<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Snap</name>
    <message>
        <location filename="../Snap.js" line="+57"/>
        <source>Snap Tools</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Narzędzia przyciągania</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show snap tools</source>
        <translation>Wyświetla narzędzia przyciągania</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>&amp;Snap</source>
        <translatorcomment>--exact match--
--file: qcad_pl.ts--
Prz&amp;yciąganie</translatorcomment>
        <translation>Przyciąga&amp;nie</translation>
    </message>
</context>
</TS>
